@@ -1,6 +1,9 @@
 
 require 'cgi'
 
+require 'aprs4r/APRS4RLogger'
+include APRS4R
+
 begin
   log4r_name = ENV['APRS4R_WEB_LOG4R'] || "/etc/aprs4r-web/aprs4r-web.log4r"
   APRS4RLogger.load_yaml_file( log4r_name)
